summaryrefslogtreecommitdiffstats
path: root/kmail/kmreaderwin.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmreaderwin.cpp')
-rw-r--r--kmail/kmreaderwin.cpp80
1 files changed, 40 insertions, 40 deletions
diff --git a/kmail/kmreaderwin.cpp b/kmail/kmreaderwin.cpp
index e7eee344..0892fbf3 100644
--- a/kmail/kmreaderwin.cpp
+++ b/kmail/kmreaderwin.cpp
@@ -150,7 +150,7 @@ NewByteArray& NewByteArray::appendNULL()
{
TQByteArray::detach();
uint len1 = size();
- if ( !TQByteArray::tqresize( len1 + 1 ) )
+ if ( !TQByteArray::resize( len1 + 1 ) )
return *this;
*(data() + len1) = '\0';
return *this;
@@ -162,7 +162,7 @@ NewByteArray& NewByteArray::operator+=( const char * newData )
TQByteArray::detach();
uint len1 = size();
uint len2 = tqstrlen( newData );
- if ( !TQByteArray::tqresize( len1 + len2 ) )
+ if ( !TQByteArray::resize( len1 + len2 ) )
return *this;
memcpy( data() + len1, newData, len2 );
return *this;
@@ -174,7 +174,7 @@ NewByteArray& NewByteArray::operator+=( const TQByteArray & newData )
TQByteArray::detach();
uint len1 = size();
uint len2 = newData.size();
- if ( !TQByteArray::tqresize( len1 + len2 ) )
+ if ( !TQByteArray::resize( len1 + len2 ) )
return *this;
memcpy( data() + len1, newData.data(), len2 );
return *this;
@@ -186,7 +186,7 @@ NewByteArray& NewByteArray::operator+=( const TQCString & newData )
TQByteArray::detach();
uint len1 = size();
uint len2 = newData.length(); // forget about the trailing 0x00 !
- if ( !TQByteArray::tqresize( len1 + len2 ) )
+ if ( !TQByteArray::resize( len1 + len2 ) )
return *this;
memcpy( data() + len1, newData.data(), len2 );
return *this;
@@ -207,7 +207,7 @@ void KMReaderWin::objectTreeToDecryptedMsg( partNode* node,
int recCount )
{
kdDebug(5006) << TQString("-------------------------------------------------" ) << endl;
- kdDebug(5006) << TQString("KMReaderWin::objectTreeToDecryptedMsg( %1 ) START").tqarg( recCount ) << endl;
+ kdDebug(5006) << TQString("KMReaderWin::objectTreeToDecryptedMsg( %1 ) START").arg( recCount ) << endl;
if( node ) {
kdDebug(5006) << node->typeString() << '/' << node->subTypeString() << endl;
@@ -309,10 +309,10 @@ kdDebug(5006) << " new Content-Type = " << headers->ContentType(
// B) Store the body of this part.
if( headers && bIsMultipart && dataNode->firstChild() ) {
-kdDebug(5006) << "is valid Multipart, processing tqchildren:" << endl;
+kdDebug(5006) << "is valid Multipart, processing children:" << endl;
TQCString boundary = headers->ContentType().Boundary().c_str();
curNode = dataNode->firstChild();
// store tqchildren of multipart
while( curNode ) {
kdDebug(5006) << "--boundary" << endl;
if( resultingData.size() &&
@@ -323,7 +323,7 @@ kdDebug(5006) << "--boundary" << endl;
resultingData += boundary;
resultingData += "\n";
// note: We are processing a harmless multipart that is *not*
// to be replaced by one of it's tqchildren, therefor
// we set their doStoreHeaders to true.
objectTreeToDecryptedMsg( curNode,
resultingData,
@@ -336,7 +336,7 @@ kdDebug(5006) << "--boundary--" << endl;
resultingData += "\n--";
resultingData += boundary;
resultingData += "--\n\n";
-kdDebug(5006) << "Multipart processing tqchildren - DONE" << endl;
+kdDebug(5006) << "Multipart processing children - DONE" << endl;
} else if( part ){
// store simple part
kdDebug(5006) << "is Simple part or invalid Multipart, storing body data .. DONE" << endl;
@@ -360,7 +360,7 @@ kdDebug(5006) << " Root node will NOT be replaced." << endl
recCount + 1 );
}
}
- kdDebug(5006) << TQString("\nKMReaderWin::objectTreeToDecryptedMsg( %1 ) END").tqarg( recCount ) << endl;
+ kdDebug(5006) << TQString("\nKMReaderWin::objectTreeToDecryptedMsg( %1 ) END").arg( recCount ) << endl;
}
@@ -1285,11 +1285,11 @@ void KMReaderWin::displaySplashPage( const TQString &info )
TQString location = locate("data", "kmail/about/main.html");
TQString content = KPIM::kFileToString(location);
- content = content.tqarg( locate( "data", "libtdepim/about/kde_infopage.css" ) );
+ content = content.arg( locate( "data", "libtdepim/about/kde_infopage.css" ) );
if ( kapp->reverseLayout() )
- content = content.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "libtdepim/about/kde_infopage_rtl.css" ) );
+ content = content.arg( "@import \"%1\";" ).arg( locate( "data", "libtdepim/about/kde_infopage_rtl.css" ) );
else
- content = content.tqarg( "" );
+ content = content.arg( "" );
mViewer->begin(KURL( location ));
@@ -1297,7 +1297,7 @@ void KMReaderWin::displaySplashPage( const TQString &info )
TQString appTitle = i18n("KMail");
TQString catchPhrase = ""; //not enough space for a catch phrase at default window size i18n("Part of the Kontact Suite");
TQString quickDescription = i18n("The email client for the K Desktop Environment.");
- mViewer->write(content.tqarg(fontSize).tqarg(appTitle).tqarg(catchPhrase).tqarg(quickDescription).tqarg(info));
+ mViewer->write(content.arg(fontSize).arg(appTitle).arg(catchPhrase).arg(quickDescription).arg(info));
mViewer->end();
}
@@ -1345,41 +1345,41 @@ void KMReaderWin::displayAboutPage()
"<p>We hope that you will enjoy KMail.</p>\n"
"<p>Thank you,</p>\n"
"<p style='margin-bottom: 0px'>&nbsp; &nbsp; The KMail Team</p>")
- .tqarg(KMAIL_VERSION) // KMail version
- .tqarg("help:/kmail/index.html") // KMail help:// URL
- .tqarg("http://kontact.kde.org/kmail/") // KMail homepage URL
- .tqarg("1.8").tqarg("3.4"); // prior KMail and KDE version
+ .arg(KMAIL_VERSION) // KMail version
+ .arg("help:/kmail/index.html") // KMail help:// URL
+ .arg("http://kontact.kde.org/kmail/") // KMail homepage URL
+ .arg("1.8").arg("3.4"); // prior KMail and KDE version
TQString featureItems;
for ( int i = 0 ; i < numKMailNewFeatures ; i++ )
- featureItems += i18n("<li>%1</li>\n").tqarg( i18n( kmailNewFeatures[i] ) );
+ featureItems += i18n("<li>%1</li>\n").arg( i18n( kmailNewFeatures[i] ) );
- info = info.tqarg( featureItems );
+ info = info.arg( featureItems );
if( kmkernel->firstStart() ) {
- info = info.tqarg( i18n("<p>Please take a moment to fill in the KMail "
+ info = info.arg( i18n("<p>Please take a moment to fill in the KMail "
"configuration panel at Settings-&gt;Configure "
"KMail.\n"
"You need to create at least a default identity and "
"an incoming as well as outgoing mail account."
"</p>\n") );
} else {
- info = info.tqarg( TQString() );
+ info = info.arg( TQString() );
}
if ( ( numKMailChanges > 1 ) || ( numKMailChanges == 1 && strlen(kmailChanges[0]) > 0 ) ) {
TQString changesText =
i18n("<p><span style='font-size:125%; font-weight:bold;'>"
"Important changes</span> (compared to KMail %1):</p>\n")
- .tqarg("1.8");
+ .arg("1.8");
changesText += "<ul>\n";
for ( int i = 0 ; i < numKMailChanges ; i++ )
- changesText += i18n("<li>%1</li>\n").tqarg( i18n( kmailChanges[i] ) );
+ changesText += i18n("<li>%1</li>\n").arg( i18n( kmailChanges[i] ) );
changesText += "</ul>\n";
- info = info.tqarg( changesText );
+ info = info.arg( changesText );
}
else
- info = info.tqarg(""); // remove the %8
+ info = info.arg(""); // remove the %8
displaySplashPage( info );
}
@@ -2142,7 +2142,7 @@ void KMReaderWin::setMsgPart( KMMessagePart* aMsgPart, bool aHTML,
}
htmlWriter()->queue("</body></html>");
htmlWriter()->flush();
- mMainWindow->setCaption(i18n("View Attachment: %1").tqarg(pname));
+ mMainWindow->setCaption(i18n("View Attachment: %1").arg(pname));
} else if (kasciistricmp(aMsgPart->typeStr(), "image")==0 ||
(kasciistricmp(aMsgPart->typeStr(), "application")==0 &&
kasciistricmp(aMsgPart->subtypeStr(), "postscript")==0))
@@ -2178,7 +2178,7 @@ void KMReaderWin::setMsgPart( KMMessagePart* aMsgPart, bool aHTML,
"\" border=\"0\">\n"
"</body></html>\n" );
htmlWriter()->end();
- setCaption( i18n("View Attachment: %1").tqarg( pname ) );
+ setCaption( i18n("View Attachment: %1").arg( pname ) );
show();
delete iio;
} else {
@@ -2198,7 +2198,7 @@ void KMReaderWin::setMsgPart( KMMessagePart* aMsgPart, bool aHTML,
htmlWriter()->queue( "</pre>" );
htmlWriter()->queue("</body></html>");
htmlWriter()->flush();
- mMainWindow->setCaption(i18n("View Attachment: %1").tqarg(pname));
+ mMainWindow->setCaption(i18n("View Attachment: %1").arg(pname));
}
// ---Sven's view text, html and image attachments in html widget end ---
}
@@ -2287,14 +2287,14 @@ void KMReaderWin::openAttachment( int id, const TQString & name )
if ( filenameText.isEmpty() )
filenameText = msgPart.name();
if ( offer ) {
- open_text = i18n("&Open with '%1'").tqarg( offer->name() );
+ open_text = i18n("&Open with '%1'").arg( offer->name() );
} else {
open_text = i18n("&Open With...");
}
const TQString text = i18n("Open attachment '%1'?\n"
"Note that opening an attachment may compromise "
"your system's security.")
- .tqarg( filenameText );
+ .arg( filenameText );
const int choice = KMessageBox::questionYesNoCancel( this, text,
i18n("Open Attachment?"), KStdGuiItem::saveAs(), open_text,
TQString::fromLatin1("askSave") + mimetype->name() ); // dontAskAgainName
@@ -2738,7 +2738,7 @@ void KMReaderWin::fillCommandInfo( partNode *node, KMMessage **msg, int *nodeId
void KMReaderWin::slotDeleteAttachment(partNode * node)
{
if ( KMessageBox::warningContinueCancel( this,
- i18n("Deleting an attachment might tqinvalidate any digital signature on this message."),
+ i18n("Deleting an attachment might invalidate any digital signature on this message."),
i18n("Delete Attachment"), KStdGuiItem::del(), "DeleteAttachmentSignatureWarning" )
!= KMessageBox::Continue ) {
return;
@@ -2794,7 +2794,7 @@ void KMReaderWin::disconnectMsgAdded()
void KMReaderWin::slotEditAttachment(partNode * node)
{
if ( KMessageBox::warningContinueCancel( this,
- i18n("Modifying an attachment might tqinvalidate any digital signature on this message."),
+ i18n("Modifying an attachment might invalidate any digital signature on this message."),
i18n("Edit Attachment"), KGuiItem( i18n("Edit"), "edit" ), "EditAttachmentSignatureWarning" )
!= KMessageBox::Continue ) {
return;
@@ -2828,12 +2828,12 @@ void KMReaderWin::scrollToAttachment( const partNode *node )
DOM::Document doc = mViewer->htmlDocument();
// The anchors for this are created in ObjectTreeParser::parseObjectTree()
- mViewer->gotoAnchor( TQString::fromLatin1( "att%1" ).tqarg( node->nodeId() ) );
+ mViewer->gotoAnchor( TQString::fromLatin1( "att%1" ).arg( node->nodeId() ) );
// Remove any old color markings which might be there
const partNode *root = node->topLevelParent();
for ( int i = 0; i <= root->totalChildCount() + 1; i++ ) {
- DOM::Element attachmentDiv = doc.getElementById( TQString( "attachmentDiv%1" ).tqarg( i + 1 ) );
+ DOM::Element attachmentDiv = doc.getElementById( TQString( "attachmentDiv%1" ).arg( i + 1 ) );
if ( !attachmentDiv.isNull() )
attachmentDiv.removeAttribute( "style" );
}
@@ -2845,14 +2845,14 @@ void KMReaderWin::scrollToAttachment( const partNode *node )
// Now, color the div of the attachment in yellow, so that the user sees what happened.
// We created a special marked div for this in writeAttachmentMarkHeader() in ObjectTreeParser,
// find and modify that now.
- DOM::Element attachmentDiv = doc.getElementById( TQString( "attachmentDiv%1" ).tqarg( node->nodeId() ) );
+ DOM::Element attachmentDiv = doc.getElementById( TQString( "attachmentDiv%1" ).arg( node->nodeId() ) );
if ( attachmentDiv.isNull() ) {
kdWarning( 5006 ) << "Could not find attachment div for attachment " << node->nodeId() << endl;
return;
}
attachmentDiv.setAttribute( "style", TQString( "border:2px solid %1" )
- .tqarg( cssHelper()->pgpWarnColor().name() ) );
+ .arg( cssHelper()->pgpWarnColor().name() ) );
// Update rendering, otherwise the rendering is not updated when the user clicks on an attachment
// that causes scrolling and the open attachment dialog
@@ -2931,8 +2931,8 @@ TQString KMReaderWin::renderAttachments(partNode * node, const TQColor &bgColor
align = "right";
if ( node->msgPart().typeStr().lower() == "message" || node == mRootNode )
html += TQString::fromLatin1("<div style=\"background:%1; %2"
- "vertical-align:middle; float:%3; %4\">").tqarg( bgColor.name() ).tqarg( margin )
- .tqarg( align ).tqarg( visibility );
+ "vertical-align:middle; float:%3; %4\">").arg( bgColor.name() ).arg( margin )
+ .arg( align ).arg( visibility );
html += subHtml;
if ( node->msgPart().typeStr().lower() == "message" || node == mRootNode )
html += "</div>";
@@ -2941,7 +2941,7 @@ TQString KMReaderWin::renderAttachments(partNode * node, const TQColor &bgColor
partNode::AttachmentDisplayInfo info = node->attachmentDisplayInfo();
if ( info.displayInHeader ) {
html += "<div style=\"float:left;\">";
- html += TQString::fromLatin1( "<span style=\"white-space:nowrap; border-width: 0px; border-left-width: 5px; border-color: %1; 2px; border-left-style: solid;\">" ).tqarg( bgColor.name() );
+ html += TQString::fromLatin1( "<span style=\"white-space:nowrap; border-width: 0px; border-left-width: 5px; border-color: %1; 2px; border-left-style: solid;\">" ).arg( bgColor.name() );
TQString fileName = writeMessagePartToTempFile( &node->msgPart(), node->nodeId() );
TQString href = node->asHREF( "header" );
html += TQString::fromLatin1( "<a href=\"" ) + href +
@@ -309,10 +309,10 @@ kdDebug(5006) << " new Content-Type = " << headers->ContentType(
TQCString boundary = headers->ContentType().Boundary().c_str();
curNode = dataNode->firstChild();
- // store tqchildren of multipart
+ // store children of multipart
while( curNode ) {
kdDebug(5006) << "--boundary" << endl;
@@ -323,7 +323,7 @@ kdDebug(5006) << "--boundary" << endl;
resultingData += "\n";
// note: We are processing a harmless multipart that is *not*
- // to be replaced by one of it's tqchildren, therefor
+ // to be replaced by one of it's children, therefor
// we set their doStoreHeaders to true.
objectTreeToDecryptedMsg( curNode,